@@ -1,5 +1,5 @@
 #' @rdname fromJSON
-toJSON <- function(x, dataframe = c("rows", "columns"), matrix = c("rowmajor", "columnmajor"),
+toJSON <- function(x, dataframe = c("rows", "columns", "values"), matrix = c("rowmajor", "columnmajor"),
   Date = c("ISO8601", "epoch"), POSIXt = c("string", "ISO8601", "epoch", "mongo"),
   factor = c("string", "integer"), complex = c("string", "list"), raw = c("base64", "hex", "mongo"),
   null = c("list", "null"), na = c("null", "string"), auto_unbox = FALSE, digits = 4,
@@ -37,28 +37,15 @@ toJSON <- function(x, dataframe = c("rows", "columns"), matrix = c("rowmajor", "
 
   #prettify
   if (isTRUE(pretty)) {
-    return(prettify(ans))
+    prettify(ans)
+  } else if(is.numeric(pretty)) {
+    prettify(ans, pretty)
   } else {
-    return(structure(ans, class="json"))
+    class(ans) <- "json"
+    return(ans)
   }
 }
 
-# maps encoding name to integer
-mapEncoding <- function(encoding) {
-  if (is.na(encoding)) {
-    return(0L)
-  }
-
-  codes <- c(unknown = 0L, native = 0L, utf8 = 1L, `utf-8` = 1L, latin1 = 2L, bytes = 3L,
-    symbol = 5L, any = 99L)
-
-  enc <- pmatch(tolower(encoding), names(codes))
-  if (is.na(enc)) {
-    stop("unrecognized encoding:", encoding)
-  }
-  return(codes[enc])
-}
-
 View <- function(x, ...){
   #workaround for View() not supporting nested data frames
   #note that utils::View also does as.data.frame. We just add format.data.frame.
